@@ -7,18 +7,21 @@ namespace py = pybind11;
 
 void init_llvm(py::module &M);
 void init_feature_module(py::module &M);
-void init_feature_module_location(py::module &M);
+void init_feature_location_module(py::module &M);
 void init_feature_model_module(py::module &M);
 void init_xml_parser(py::module &M);
+void init_xml_writer(py::module &M);
 
 PYBIND11_MODULE(vara_feature, M) {
   auto LLVMModule = M.def_submodule("llvm_util");
   init_llvm(M);
   auto FeatureModule = M.def_submodule("feature");
   init_feature_module(FeatureModule);
-  init_feature_module_location(FeatureModule);
+  init_feature_location_module(FeatureModule);
   auto FeatureModelModule = M.def_submodule("feature_model");
   init_feature_model_module(FeatureModelModule);
   auto FMParserModule = M.def_submodule("fm_parsers");
   init_xml_parser(FMParserModule);
+  auto FMWriterModule = M.def_submodule("fm_writer");
+  init_xml_writer(FMWriterModule);
 }
